==> CSharp_2.1.3.20080114.zip: CSharp/AdvancedServoExamples/AdvancedServo-full/AdvancedServo-full/Form1.cs <==
/* This example simply displays the Phidget AdvancedServo information when it is attached and displays 
 * the servo positions, velocity, and current with a slider for position, velocity, and acceleration manipulation.
 *
 * Please note that this example was designed to work with only one Phidget AdvanceServo connected. 
 * For an example using multiple Phidget AdvancedServos, please see a "multiple" example in the 
 * AdvancedServos Examples folder.
 *
 * Copyright 2007 Phidgets Inc.  
 * This work is licensed under the Creative Commons Attribution 2.5 Canada License. 
 * To view a copy of this license, visit http://creativecommons.org/licenses/by/2.5/ca/
 */

using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;
using Phidgets;  //for the servo class and the exceptions class
using Phidgets.Events; //for the event handling classes

namespace AdvancedServo_full
{
    public partial class Form1 : Form
    {
        private AdvancedServo advServo; //Declare an advancedservo object

        public Form1()
        {
            InitializeComponent();
        }

        //Initialization code
        private void Form1_Load(object sender, EventArgs e)
        {
            advServo = new AdvancedServo();

            advServo.Attach += new AttachEventHandler(advServo_Attach);
            advServo.Detach += new DetachEventHandler(advServo_Detach);
            advServo.Error += new ErrorEventHandler(advServo_Error);

            advServo.CurrentChange += new CurrentChangeEventHandler(advServo_CurrentChange);
            advServo.PositionChange += new PositionChangeEventHandler(advServo_PositionChange);
            advServo.VelocityChange += new VelocityChangeEventHandler(advServo_VelocityChange);

            //This assumes that if there is a command line argument, it is a serial number
            //and we try to open that specific device. Otherwise, open any device.
            String[] args = Environment.GetCommandLineArgs();
            if (args.Length > 2 && args[2].Equals("remote"))
                advServo.open(int.Parse(args[1]), null);
            else if (args.Length > 1)
                advServo.open(int.Parse(args[1]));
            else
                advServo.open();
        }

        //PhidgetServo attach event handling code
        void advServo_Attach(object sender, AttachEventArgs e)
        {
            AdvancedServo attached = (AdvancedServo)sender;

            positionTrk.SetRange((int)advServo.servos[0].PositionMin, (int)advServo.servos[0].PositionMax);
            velocityTrk.SetRange((int)advServo.servos[0].VelocityMin, (int)advServo.servos[0].VelocityMax);
            accelTrk.SetRange((int)advServo.servos[0].AccelerationMin, (int)advServo.servos[0].AccelerationMax);

            attachedTxt.Text = attached.Attached.ToString();
            nameTxt.Text = attached.Name;
            serialTxt.Text = attached.SerialNumber.ToString();
            versiontxt.Text = attached.Version.ToString();
            numServosTxt.Text = attached.servos.Count.ToString();

            //this will enagare all servos - at the same time initializing all servo state
            foreach (AdvancedServoServo servo in attached.servos)
                servo.Engaged = true;

            for (int i = 0; i < attached.servos.Count; i++)
            {
                servoCmb.Items.Add(i);
            }

            //this will initialize all values
            servoCmb.SelectedIndex = 0;
            servoCmb.Enabled = true;

            velocityTrk.Enabled = true;
            positionTrk.Enabled = true;
            accelTrk.Enabled = true;
            engagedCheckBox.Enabled = true;
            speedRampingCheckBox.Enabled = true;
        }

        //PhidgetServo detach event handling code
        void advServo_Detach(object sender, DetachEventArgs e)
        {
            AdvancedServo detached = (AdvancedServo)sender;

            attachedTxt.Text = detached.Attached.ToString();
            nameTxt.Clear();
            serialTxt.Clear();
            versiontxt.Clear();
            numServosTxt.Clear();

            velocityTrk.Enabled = false;
            velocityTrk.Value = velocityTrk.Minimum;
            positionTrk.Enabled = false;
            positionTrk.Value = positionTrk.Minimum;
            accelTrk.Enabled = false;
            accelTrk.Value = accelTrk.Minimum;
            engagedCheckBox.Enabled = false;
            speedRampingCheckBox.Enabled = false;

            target_positionTxt.Clear();
            target_velocityTxt.Clear();
            accelTxt.Clear();

            servoCmb = new ComboBox();
            servoCmb.Enabled = false;
        }

        void advServo_Error(object sender, ErrorEventArgs e)
        {
            MessageBox.Show(e.Description);
        }

        //Servo current change event handling code
        void advServo_CurrentChange(object sender, CurrentChangeEventArgs e)
        {
            if (e.Index == (int)servoCmb.SelectedItem)
            {
                currentTxt.Text = e.Current.ToString();
            }
        }

        //Servo position change event handling code
        void advServo_PositionChange(object sender, PositionChangeEventArgs e)
        {
            if (e.Index == (int)servoCmb.SelectedItem)
            {
                actual_positionTxt.Text = e.Position.ToString();
            }
        }

        //Servo velocity change event handling code
        void advServo_VelocityChange(object sender, VelocityChangeEventArgs e)
        {
            if (e.Index == (int)servoCmb.SelectedItem)
            {
                actual_velocityTxt.Text = e.Velocity.ToString();
            }
        }

        //this code will switch between the selected servos and display their position, velocity, accelertaion, and current data
        private void servoCmb_SelectedIndexChanged(object sender, EventArgs e)
        {
            int index = (int)servoCmb.SelectedItem;

            //Use a try-catch block around code where you are getting and displaying the servo data
            //if the current position state has yet to be set, it will throw a PhidgetException for value not set
            //you can use this to test this and to display that the value is unknown
            try
            {
                engagedCheckBox.Checked = advServo.servos[index].Engaged;

                actual_positionTxt.Text = advServo.servos[index].Position.ToString();
                positionTrk.Value = (int)advServo.servos[index].Position;
                target_positionTxt.Text = advServo.servos[index].Position.ToString();

                currentTxt.Text = advServo.servos[index].Current.ToString();

                actual_velocityTxt.Text = advServo.servos[index].Velocity.ToString();
                velocityTrk.Value = (int)advServo.servos[index].MaxVelocity;
                target_velocityTxt.Text = advServo.servos[index].MaxVelocity.ToString();

                accelTrk.Value = (int)advServo.servos[index].Acceleration;
                accelTxt.Text = advServo.servos[index].Acceleration.ToString();

                speedRampingCheckBox.Checked = advServo.servos[index].SpeedRamping;
            }
            catch (PhidgetException)
            {
                actual_positionTxt.Text = "Unknown";
                actual_velocityTxt.Text = "Unknown";
                currentTxt.Text = "Unknown";

                positionTrk.Value = (int)advServo.servos[0].PositionMin;
                velocityTrk.Value = (int)advServo.servos[0].VelocityMin;
                accelTrk.Value = (int)advServo.servos[0].AccelerationMin;

                target_positionTxt.Text = positionTrk.Value.ToString();
                target_velocityTxt.Text = velocityTrk.Value.ToString();
                accelTxt.Text = accelTrk.Value.ToString();
            }
        }

        //Modify the servo acceleration proprty based on the value returned by the slider
        private void accelTrk_Scroll(object sender, EventArgs e)
        {
            try
            {
                advServo.servos[(int)servoCmb.SelectedItem].Acceleration = accelTrk.Value;
                accelTxt.Text = accelTrk.Value.ToString();
            }
            catch (PhidgetException ex)
            {
                MessageBox.Show(ex.Description);
            }
        }

        //Modify the servo position based on the value returned by the slider
        private void positionTrk_Scroll(object sender, EventArgs e)
        {
            //A PhidgetException will be thrown if you try to set the position to any value NOT between -23 and 232
            try
            {
                advServo.servos[(int)servoCmb.SelectedItem].Position = positionTrk.Value;
                target_positionTxt.Text = positionTrk.Value.ToString();
            }
            catch (PhidgetException ex)
            {
                MessageBox.Show(ex.Description);
            }
        }

        //Modify the servo velocity property based on the value returned by the slider
        private void velocityTrk_Scroll(object sender, EventArgs e)
        {
            try
            {
                advServo.servos[(int)servoCmb.SelectedItem].MaxVelocity = velocityTrk.Value;
                target_velocityTxt.Text = velocityTrk.Value.ToString();
            }
            catch (PhidgetException ex)
            {
                MessageBox.Show(ex.Description);
            }
        }

        //When the application is terminating, close the Phidget.
        private void Form1_FormClosed(object sender, FormClosedEventArgs e)
        {
            advServo.Attach -= new AttachEventHandler(advServo_Attach);
            advServo.Detach -= new DetachEventHandler(advServo_Detach);
            advServo.Error -= new ErrorEventHandler(advServo_Error);

            advServo.CurrentChange -= new CurrentChangeEventHandler(advServo_CurrentChange);
            advServo.PositionChange -= new PositionChangeEventHandler(advServo_PositionChange);
            advServo.VelocityChange -= new VelocityChangeEventHandler(advServo_VelocityChange);

            //run any events in the message queue - otherwise close will hang if there are any outstanding events
            Application.DoEvents();

            advServo.close();
            advServo = null;
        }

        private void engagedCheckBox_CheckedChanged(object sender, EventArgs e)
        {
            advServo.servos[(int)servoCmb.SelectedItem].Engaged = engagedCheckBox.Checked;
        }

        private void speedRampingCheckBox_CheckedChanged(object sender, EventArgs e)
        {
            advServo.servos[(int)servoCmb.SelectedItem].SpeedRamping = speedRampingCheckBox.Checked;
        }
    }
}

==> CSharp_2.1.3.20080303.zip: CSharp/AdvancedServoExamples/AdvancedServo-full/AdvancedServo-full/Form1.cs <==
/* This example simply displays the Phidget AdvancedServo information when it is attached and displays 
 * the servo positions, velocity, and current with a slider for position, velocity, and acceleration manipulation.
 *
 * Please note that this example was designed to work with only one Phidget AdvanceServo connected. 
 * For an example using multiple Phidget AdvancedServos, please see a "multiple" example in the 
 * AdvancedServos Examples folder.
 *
 * Copyright 2007 Phidgets Inc.  
 * This work is licensed under the Creative Commons Attribution 2.5 Canada License. 
 * To view a copy of this license, visit http://creativecommons.org/licenses/by/2.5/ca/
 */

using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;
using Phidgets;  //for the servo class and the exceptions class
using Phidgets.Events; //for the event handling classes

namespace AdvancedServo_full
{
    public partial class Form1 : Form
    {
        private AdvancedServo advServo; //Declare an advancedservo object

        public Form1()
        {
            InitializeComponent();
        }

        //Initialization code
        private void Form1_Load(object sender, EventArgs e)
        {
            advServo = new AdvancedServo();

            advServo.Attach += new AttachEventHandler(advServo_Attach);
            advServo.Detach += new DetachEventHandler(advServo_Detach);
            advServo.Error += new ErrorEventHandler(advServo_Error);

            advServo.CurrentChange += new CurrentChangeEventHandler(advServo_CurrentChange);
            advServo.PositionChange += new PositionChangeEventHandler(advServo_PositionChange);
            advServo.VelocityChange += new VelocityChangeEventHandler(advServo_VelocityChange);

            //This assumes that if there is a command line argument, it is a serial number
            //and we try to open that specific device. Otherwise, open any device.
            String[] args = Environment.GetCommandLineArgs();
            if (args.Length > 2 && args[2].Equals("remote"))
                advServo.open(int.Parse(args[1]), null);
            else if (args.Length > 1)
                advServo.open(int.Parse(args[1]));
            else
                advServo.open();
        }

        //PhidgetServo attach event handling code
        void advServo_Attach(object sender, AttachEventArgs e)
        {
            AdvancedServo attached = (AdvancedServo)sender;

            positionTrk.SetRange((int)advServo.servos[0].PositionMin, (int)advServo.servos[0].PositionMax);
            velocityTrk.SetRange((int)advServo.servos[0].VelocityMin, (int)advServo.servos[0].VelocityMax);
            accelTrk.SetRange((int)advServo.servos[0].AccelerationMin, (int)advServo.servos[0].AccelerationMax);

            attachedTxt.Text = attached.Attached.ToString();
            nameTxt.Text = attached.Name;
            serialTxt.Text = attached.SerialNumber.ToString();
            versiontxt.Text = attached.Version.ToString();
            numServosTxt.Text = attached.servos.Count.ToString();

            //this will enagage all servos - at the same time initializing all servo state
            //foreach (AdvancedServoServo servo in attached.servos)
            //    servo.Engaged = true;

            for (int i = 0; i < attached.servos.Count; i++)
            {
                servoCmb.Items.Add(i);
            }

            //this will initialize all values
            servoCmb.SelectedIndex = 0;
            servoCmb.Enabled = true;

            velocityTrk.Enabled = true;
            positionTrk.Enabled = true;
            accelTrk.Enabled = true;
            engagedCheckBox.Enabled = true;
            speedRampingCheckBox.Enabled = true;
        }

        //PhidgetServo detach event handling code
        void advServo_Detach(object sender, DetachEventArgs e)
        {
            AdvancedServo detached = (AdvancedServo)sender;

            attachedTxt.Text = detached.Attached.ToString();
            nameTxt.Clear();
            serialTxt.Clear();
            versiontxt.Clear();
            numServosTxt.Clear();

            velocityTrk.Enabled = false;
            velocityTrk.Value = velocityTrk.Minimum;
            positionTrk.Enabled = false;
            positionTrk.Value = positionTrk.Minimum;
            accelTrk.Enabled = false;
            accelTrk.Value = accelTrk.Minimum;
            engagedCheckBox.Enabled = false;
            speedRampingCheckBox.Enabled = false;

            target_positionTxt.Clear();
            target_velocityTxt.Clear();
            accelTxt.Clear();

            servoCmb = new ComboBox();
            servoCmb.Enabled = false;
        }

        void advServo_Error(object sender, ErrorEventArgs e)
        {
            MessageBox.Show(e.Description);
        }

        //Servo current change event handling code
        void advServo_CurrentChange(object sender, CurrentChangeEventArgs e)
        {
            if (e.Index == (int)servoCmb.SelectedItem)
            {
                currentTxt.Text = e.Current.ToString();
            }
        }

        //Servo position change event handling code
        void advServo_PositionChange(object sender, PositionChangeEventArgs e)
        {
            if (e.Index == (int)servoCmb.SelectedItem)
            {
                actual_positionTxt.Text = e.Position.ToString();
            }
        }

        //Servo velocity change event handling code
        void advServo_VelocityChange(object sender, VelocityChangeEventArgs e)
        {
            if (e.Index == (int)servoCmb.SelectedItem)
            {
                actual_velocityTxt.Text = e.Velocity.ToString();
            }
        }

        //this code will switch between the selected servos and display their position, velocity, accelertaion, and current data
        private void servoCmb_SelectedIndexChanged(object sender, EventArgs e)
        {
            int index = (int)servoCmb.SelectedItem;

            //Use a try-catch block around code where you are getting and displaying the servo data
            //if the current position state has yet to be set, it will throw a PhidgetException for value not set
            //you can use this to test this and to display that the value is unknown
            try
            {
                engagedCheckBox.Checked = advServo.servos[index].Engaged;

                speedRampingCheckBox.Checked = advServo.servos[index].SpeedRamping;

                if (advServo.servos[index].Engaged)
                {
                    actual_positionTxt.Text = advServo.servos[index].Position.ToString();
                    positionTrk.Value = (int)advServo.servos[index].Position;
                    target_positionTxt.Text = advServo.servos[index].Position.ToString();
                }

                currentTxt.Text = advServo.servos[index].Current.ToString();

                actual_velocityTxt.Text = advServo.servos[index].Velocity.ToString();

                velocityTrk.Value = (int)advServo.servos[index].MaxVelocity;
                target_velocityTxt.Text = advServo.servos[index].MaxVelocity.ToString();

                accelTrk.Value = (int)advServo.servos[index].Acceleration;
                accelTxt.Text = advServo.servos[index].Acceleration.ToString();
            }
            catch (PhidgetException)
            {
                actual_positionTxt.Text = "Unknown";
                actual_velocityTxt.Text = "Unknown";
                currentTxt.Text = "Unknown";

                positionTrk.Value = (int)advServo.servos[0].PositionMin;
                velocityTrk.Value = (int)advServo.servos[0].VelocityMin;
                accelTrk.Value = (int)advServo.servos[0].AccelerationMin;

                target_positionTxt.Text = positionTrk.Value.ToString();
                target_velocityTxt.Text = velocityTrk.Value.ToString();
                accelTxt.Text = accelTrk.Value.ToString();
            }
        }

        //Modify the servo acceleration proprty based on the value returned by the slider
        private void accelTrk_Scroll(object sender, EventArgs e)
        {
            try
            {
                advServo.servos[(int)servoCmb.SelectedItem].Acceleration = accelTrk.Value;
                accelTxt.Text = accelTrk.Value.ToString();
            }
            catch (PhidgetException ex)
            {
                MessageBox.Show(ex.Description);
            }
        }

        //Modify the servo position based on the value returned by the slider
        private void positionTrk_Scroll(object sender, EventArgs e)
        {
            //A PhidgetException will be thrown if you try to set the position to any value NOT between -23 and 232
            try
            {
                advServo.servos[(int)servoCmb.SelectedItem].Position = positionTrk.Value;
                target_positionTxt.Text = positionTrk.Value.ToString();
            }
            catch (PhidgetException ex)
            {
                MessageBox.Show(ex.Description);
            }
        }

        //Modify the servo velocity property based on the value returned by the slider
        private void velocityTrk_Scroll(object sender, EventArgs e)
        {
            try
            {
                advServo.servos[(int)servoCmb.SelectedItem].MaxVelocity = velocityTrk.Value;
                target_velocityTxt.Text = velocityTrk.Value.ToString();
            }
            catch (PhidgetException ex)
            {
                MessageBox.Show(ex.Description);
            }
        }

        //When the application is terminating, close the Phidget.
        private void Form1_FormClosed(object sender, FormClosedEventArgs e)
        {
            advServo.Attach -= new AttachEventHandler(advServo_Attach);
            advServo.Detach -= new DetachEventHandler(advServo_Detach);
            advServo.Error -= new ErrorEventHandler(advServo_Error);

            advServo.CurrentChange -= new CurrentChangeEventHandler(advServo_CurrentChange);
            advServo.PositionChange -= new PositionChangeEventHandler(advServo_PositionChange);
            advServo.VelocityChange -= new VelocityChangeEventHandler(advServo_VelocityChange);

            //run any events in the message queue - otherwise close will hang if there are any outstanding events
            Application.DoEvents();

            advServo.close();
            advServo = null;
        }

        private void engagedCheckBox_CheckedChanged(object sender, EventArgs e)
        {
            advServo.servos[(int)servoCmb.SelectedItem].Engaged = engagedCheckBox.Checked;
        }

        private void speedRampingCheckBox_CheckedChanged(object sender, EventArgs e)
        {
            advServo.servos[(int)servoCmb.SelectedItem].SpeedRamping = speedRampingCheckBox.Checked;
        }
    }
}
